@@ -59,8 +59,12 @@ class Generation:
             fp.writelines([os.linesep] * self.LINESEP_NUM)
 
     def write_class_dom(self, file_name=None):
+        if not self._class_info:
+            return None
         file_name = file_name if file_name else "class_domain"
         dst = os.path.join(self._working_dir, file_name + ".yaml")
+        if os.path.exists(dst):
+            os.remove(dst)
         self.write_dsdl_version(path=dst)
         with open(dst, "a") as fp:
             for class_domain in self._class_info:
@@ -68,9 +72,9 @@ class Generation:
                     continue
                 self._yaml_obj["class_dom"].dump(class_domain.format(), fp)
                 fp.writelines([os.linesep] * self.LINESEP_NUM)
-                if class_domain.parent_domain:
-                    self._yaml_obj["class_dom"].dump(class_domain.parent_domain.format(), fp)
-                fp.writelines([os.linesep] * self.LINESEP_NUM)
+                # if class_domain.parent_domain:
+                #     self._yaml_obj["class_dom"].dump(class_domain.parent_domain.format(), fp)
+                # fp.writelines([os.linesep] * self.LINESEP_NUM)
         return file_name
 
     def _write_struct_item(self, struct_item, file_name=None, path=None):
@@ -86,6 +90,8 @@ class Generation:
     def write_struct_def(self, file_name):
 
         dst = os.path.join(self._working_dir, file_name + ".yaml")
+        if os.path.exists(dst):
+            os.remove(dst)
         self.write_dsdl_version(path=dst)
 
         for struct_def_item in self._def_info:
@@ -108,8 +114,10 @@ class Generation:
 
         yaml_file = file_name + ".yaml"
         dst = os.path.join(self._working_dir, yaml_file)
+        if os.path.exists(dst):
+            os.remove(dst)
         self.write_dsdl_version(path=dst)
-        self.write_import_list(import_list, path=dst)
+        self.write_import_list([_ for _ in import_list if _], path=dst)
         self.write_meta(path=dst)
 
         if not self.separate_flag:
